# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------
from azure.cli.core.commands import register_cli_argument, CliArgumentType

from azure.cli.core.commands.parameters import (
    tags_type,
    resource_group_name_type,
    get_resource_name_completion_list)

name_arg_type = CliArgumentType(options_list=('--name', '-n'), metavar='NAME')

register_cli_argument('cognitiveservices', 'account_name',
                      arg_type=name_arg_type, help='cognitive service account name',
                      completer=get_resource_name_completion_list(
                          'Microsoft.CognitiveServices/accounts'))
register_cli_argument('cognitiveservices', 'resource_group_name',
                      arg_type=resource_group_name_type)
register_cli_argument('cognitiveservices', 'sku_name', options_list=('--sku',),
                      help='the Sku of cognitive services account')
register_cli_argument('cognitiveservices', 'kind',
                      help='the API name of cognitive services account')
register_cli_argument('cognitiveservices', 'tags', tags_type)
register_cli_argument('cognitiveservices', 'key_name', required=True,
                      help='Key name to generate', choices=['key1', 'key2'])
register_cli_argument('cognitiveservices account create', 'yes', action='store_true',
                      help='Do not prompt for terms confirmation')



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------
# management client factories


def get_cognitiveservices_management_client(_):
    from azure.cli.core.commands.client_factory import get_mgmt_service_client
    from azure.mgmt.cognitiveservices import CognitiveServicesManagementClient
    return get_mgmt_service_client(CognitiveServicesManagementClient, location='notused')


def get_cognitiveservices_account_operations(kwargs):
    return get_cognitiveservices_management_client(kwargs).cognitive_services_accounts


def get_cognitiveservices_operations(kwargs):
    return get_cognitiveservices_management_client(kwargs).accounts



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------
from azure.cli.core.commands import cli_command
from azure.cli.command_modules.cognitiveservices._client_factory import (
    get_cognitiveservices_account_operations,
    get_cognitiveservices_operations)

mgmt_path = 'azure.mgmt.cognitiveservices.operations.cognitive_services_accounts_operations#'\
    'CognitiveServicesAccountsOperations.{}'
custom_path = 'azure.cli.command_modules.cognitiveservices.custom#{}'

cli_command(__name__, 'cognitiveservices account create', custom_path.format('create'),
            get_cognitiveservices_account_operations)
cli_command(__name__, 'cognitiveservices account delete', mgmt_path.format('delete'),
            get_cognitiveservices_account_operations)
cli_command(__name__, 'cognitiveservices account show', mgmt_path.format('get_properties'),
            get_cognitiveservices_account_operations)
cli_command(__name__, 'cognitiveservices list', custom_path.format('listresources'),
            get_cognitiveservices_operations)
cli_command(__name__, 'cognitiveservices account update', custom_path.format('update'),
            get_cognitiveservices_account_operations)
cli_command(__name__, 'cognitiveservices account keys regenerate',
            mgmt_path.format('regenerate_key'),
            get_cognitiveservices_account_operations)
cli_command(__name__, 'cognitiveservices account keys list', mgmt_path.format('list_keys'),
            get_cognitiveservices_account_operations)
cli_command(__name__, 'cognitiveservices account list-skus', mgmt_path.format('list_skus'),
            get_cognitiveservices_account_operations)



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------
from azure.mgmt.cognitiveservices.models import CognitiveServicesAccountCreateParameters, Sku
from azure.cli.core.prompting import prompt_y_n
from azure.cli.core.util import CLIError

import azure.cli.core.azlogging as azlogging
logger = azlogging.get_az_logger(__name__)


def listresources(client, resource_group_name=None):
    if resource_group_name:
        return client.list_by_resource_group(resource_group_name)
    else:
        return client.list()


# pylint: disable=too-many-arguments
def create(
        client, resource_group_name, account_name, sku_name, kind, location, tags=None, yes=None):

    terms = 'Notice\nMicrosoft will use data you send to the Cognitive'\
        'Services to improve Microsoft products and services.'\
        'For example we may use content that you provide to the Cognitive'\
        'Services to improve our underlying algorithms and models over time.'\
        'Where you send personal data to the Cognitive Services, you are responsible'\
        'for obtaining sufficient consent from the data subjects.'\
        'The General Privacy and Security Terms in the Online Services Terms '\
        '(https://www.microsoft.com/en-us/Licensing/product-licensing/products.aspx) '\
        'do not apply to the Cognitive Services.'\
        'You must comply with use and display requirements for the Bing Search APIs.'\
        '\n\nPlease refer to the Microsoft Cognitive Services section in the Online '\
        'Services Terms for details.'
    hint = '\nPlease select'
    if yes:
        logger.warning(terms)
    else:
        logger.warning(terms)
        option = prompt_y_n(hint)
        if not option:
            raise CLIError('Operation cancelled.')
    sku = Sku(sku_name)
    properties = {}
    params = CognitiveServicesAccountCreateParameters(sku, kind, location, properties, tags)
    return client.create(resource_group_name, account_name, params)


def update(client, resource_group_name, account_name, sku_name=None, tags=None):
    sku = Sku(sku_name)
    return client.update(resource_group_name, account_name, sku, tags)



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from azure.cli.core.help_files import helps

helps['cognitiveservices list'] = """
    type: command
    short-summary: list all the existing cognitive services accounts under a resource group or current azure subscription
    examples:
        - name: list all the cognitive services accounts in a resource group
          text: az cognitiveservices list -g MyResourceGroup
"""

helps['cognitiveservices account'] = """
    type: group
    short-summary: Manage and update cognitive services accounts
"""

helps['cognitiveservices account delete'] = """
    type: command
    short-summary: Remove a cognitive services account.
"""

helps['cognitiveservices account create'] = """
    type: command
    short-summary: Create a cognitive services account.
    examples:
        - name: create a S0 face Api cognitive services account in West Europe without confirmation required
          text: az cognitiveservices create -n myresource -g myResourceGroup --kind Face --sku S0 -l WestEurope --yes
"""

helps['cognitiveservices account show'] = """
    type: command
    short-summary: Get the details of a cognitive services account.
"""

helps['cognitiveservices account update'] = """
    type: command
    short-summary: Update the properties of a cognitive services account.
"""

helps['cognitiveservices account list-skus'] = """
    type: command
    short-summary: List the avaiable skus of a cognitive services account.
"""


helps['cognitiveservices account keys'] = """
    type: group
    short-summary: Manage the keys of a cognitive services account.
"""

helps['cognitiveservices account keys regenerate'] = """
    type: command
    short-summary: Regenerate the keys of a cognitive services account.
"""

helps['cognitiveservices account keys list'] = """
    type: command
    short-summary: List the keys of a cognitive services account.
"""
